==> pdf-model-1.26.1-sources.jar: org/verapdf/model/xmplayer/XMPProperty.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.List;

		
/**
* XMP property
*/
public interface XMPProperty extends XMPObject {
	

	/**
	* true if this property is predefined (available in predefined schema) for PDF/A-1
	*/
	public Boolean getisPredefinedInXMP2004();

	/**
	* true if this property is predefined (available in predefined schema) for PDF/A-2 or for PDF/A-3
	*/
	public Boolean getisPredefinedInXMP2005();

	/**
	* true if this property defined in extension schema in current XMP package
	*/
	public Boolean getisDefinedInCurrentPackage();

	/**
	* true if this property defined in extension schema in main XMP package
	*/
	public Boolean getisDefinedInMainPackage();

	/**
	* true if the property value type corresponds to the type defined by XMP specification or extension schema
	*/
	public Boolean getisValueTypeCorrect();

	/**
	* type defined by XMP specification or extension schema
	*/
	public String getpredefinedType();
}

==> pdf-model-1.27.10-sources.jar: org/verapdf/model/xmplayer/XMPProperty.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015-2024, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.xmplayer;
		
import org.verapdf.model.baselayer.Object;
import java.util.Set;

		
/**
* XMP property
*/
public interface XMPProperty extends XMPObject {
	

	/**
	* true if this property is predefined (available in predefined schema) for PDF/A-1
	*/
	public Boolean getisPredefinedInXMP2004();

	/**
	* true if this property is predefined (available in predefined schema) for PDF/A-2 or for PDF/A-3
	*/
	public Boolean getisPredefinedInXMP2005();

	/**
	* true if this property defined in extension schema in current XMP package
	*/
	public Boolean getisDefinedInCurrentPackage();

	/**
	* true if this property defined in extension schema in main XMP package
	*/
	public Boolean getisDefinedInMainPackage();

	/**
	* true if the property value type corresponds to the type defined by XMP specification or extension schema
	*/
	public Boolean getisValueTypeCorrect();

	/**
	* type defined by XMP specification or extension schema
	*/
	public String getpredefinedType();
}
